use rsw;

#[tokio::main]
async fn main() {
    rsw::rsw_cli();
}
